@@ -14,6 +14,7 @@ unit test submodules.
 # ....................{ IMPORTS                           }....................
 import collections, typing
 from collections import namedtuple
+from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
 
 # ....................{ TYPEVARS                          }....................
 S = typing.TypeVar('S')
@@ -27,6 +28,19 @@ T = typing.TypeVar('T')
 User-defined generic :mod:`typing` type variable.
 '''
 
+
+_IS_TYPING_ATTR_TYPEVARED = not IS_PYTHON_AT_LEAST_3_9
+'''
+``True`` only if **argumentless typing attributes** (i.e., public attribute of
+the :mod:`typing` module without arguments) are parametrized by one or more
+type variables under the active Python interpreter.
+
+This boolean is ``True`` for *all* Python interpreters targeting less than
+Python 3.9.0. Prior to Python 3.9.0, the :mod:`typing` module parametrized most
+argumentless typing attributes by default. Python 3.9.0 halted this barbaric
+practice by leaving argumentless typing attributes unparametrized by default.
+'''
+
 # ....................{ GENERICS ~ single                 }....................
 class PepGenericTypevaredSingle(typing.Generic[S, T]):
     '''
@@ -179,10 +193,7 @@ exception_str_not_match_regexes : tuple
 '''
 
 # ....................{ METADATA ~ dict : attr            }....................
-#FIXME: Explicitly list all other types thought not to be supported currently
-#(e.g., "typing.IO").
-#FIXME: Explicitly list all other types thought to be supported currently
-#(e.g., "typing.AbstractSet").
+#FIXME: Explicitly list all other "typing" types (e.g., "typing.IO").
 PEP_HINT_TO_META = {
     # ..................{ CALLABLES                         }..................
     typing.Callable[[], str]: _PepHintMetadata(
@@ -226,11 +237,12 @@ PEP_HINT_TO_META = {
     ),
 
     # ..................{ COLLECTIONS ~ dict                }..................
+    # Argumentless "Dict" attribute.
     typing.Dict: _PepHintMetadata(
         typing_attr=typing.Dict,
-        is_supported=False,
+        is_supported=not _IS_TYPING_ATTR_TYPEVARED,
         is_generic_user=False,
-        is_typevared=True,
+        is_typevared=_IS_TYPING_ATTR_TYPEVARED,
         piths_satisfied=(
             # Dictionary containing arbitrary key-value pairs.
             {
@@ -250,6 +262,7 @@ PEP_HINT_TO_META = {
             ),
         ),
     ),
+
     typing.Dict[int, str]: _PepHintMetadata(
         typing_attr=typing.Dict,
         is_supported=True,
@@ -281,12 +294,12 @@ PEP_HINT_TO_META = {
     ),
 
     # ..................{ COLLECTIONS ~ list                }..................
-    # Bare "List" attribute.
+    # Argumentless "List" attribute.
     typing.List: _PepHintMetadata(
         typing_attr=typing.List,
-        is_supported=False,
+        is_supported=not _IS_TYPING_ATTR_TYPEVARED,
         is_generic_user=False,
-        is_typevared=True,
+        is_typevared=_IS_TYPING_ATTR_TYPEVARED,
         piths_satisfied=(
             # Empty list, which satisfies all hint arguments by definition.
             [],
@@ -298,13 +311,19 @@ PEP_HINT_TO_META = {
             ],
         ),
         piths_unsatisfied_meta=(
+            # String constant.
+            _PepHintPithUnsatisfiedMetadata(
+                pith='Of acceptance.',
+                exception_str_match_regexes=(),
+                exception_str_not_match_regexes=(),
+            ),
             # Tuple containing arbitrary items.
             _PepHintPithUnsatisfiedMetadata(
-                pith=[
+                pith=(
                     'Of their godliest Tellurion’s utterance —“Șuper‐ior!”;',
                     '3. And Utter‐most, gutterly gut‐rending posts, glutton',
                     3.1415,
-                ],
+                ),
                 exception_str_match_regexes=(),
                 exception_str_not_match_regexes=(),
             ),
@@ -524,9 +543,9 @@ PEP_HINT_TO_META = {
     # ..................{ TYPE ALIASES                      }..................
     typing.Type: _PepHintMetadata(
         typing_attr=typing.Type,
-        is_supported=False,
+        is_supported=not _IS_TYPING_ATTR_TYPEVARED,
         is_generic_user=False,
-        is_typevared=True,
+        is_typevared=_IS_TYPING_ATTR_TYPEVARED,
         piths_satisfied=(
             # Transitive superclass of all superclasses.
             object,
@@ -597,6 +616,25 @@ PEP_HINT_TO_META = {
     # For this reason, these arguments *MUST* be omitted below.
     # !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
+    # Ignorable bare "Union" attribute.
+    typing.Union: _PepHintMetadata(
+        typing_attr=typing.Union,
+        is_supported=True,
+        is_generic_user=False,
+        is_typevared=False,
+        piths_satisfied=(
+            # Empty list, which satisfies all hint arguments by definition.
+            [],
+            # Set containing arbitrary items.
+            {
+                'We were mysteries, unwon',
+                'We donned apportionments',
+                37.73,
+            },
+        ),
+        piths_unsatisfied_meta=(),
+    ),
+
     # Union of one non-"typing" type and an originative "typing" type,
     # exercising an edge case.
     typing.Union[int, typing.Sequence[str]]: _PepHintMetadata(
@@ -758,13 +796,39 @@ PEP_HINT_TO_META = {
     ),
 
     # ..................{ UNIONS ~ optional                 }..................
+    # Ignorable bare "Optional" attribute.
+    typing.Optional: _PepHintMetadata(
+        typing_attr=typing.Optional,
+        is_supported=True,
+        is_generic_user=False,
+        is_typevared=False,
+        piths_satisfied=(
+            # Empty tuple, which satisfies all hint arguments by definition.
+            (),
+            # Dictionary containing arbitrary key-value pairs.
+            {
+                'Of': 'dung and',
+                'Called': 'it dunne and',
+            },
+        ),
+        piths_unsatisfied_meta=(),
+    ),
+
     # Optional isinstance()-able "typing" type.
     typing.Optional[typing.Sequence[str]]: _PepHintMetadata(
-        # The "typing" module implicitly reduces *ALL* subscriptions of the
-        # "typing.Optional" attribute by the corresponding "typing.Union"
-        # attribute subscripted by both that argument and "type(None)". Ergo,
-        # there effectively exists *NO* "typing.Optional" attribute.
-        typing_attr=typing.Union,
+        # Subscriptions of the "typing.Optional" attribute reduce to
+        # fundamentally different argumentless typing attributes depending on
+        # Python version. Specifically, under:
+        # * Python >= 3.9.0, the "typing.Optional" and "typing.Union"
+        #   attributes are distinct.
+        # * Python < 3.9.0, the "typing.Optional" and "typing.Union"
+        #   attributes are *NOT* distinct. The "typing" module implicitly
+        #   reduces *ALL* subscriptions of the "typing.Optional" attribute by
+        #   the corresponding "typing.Union" attribute subscripted by both that
+        #   argument and "type(None)". Ergo, there effectively exists *NO*
+        #   "typing.Optional" attribute under older Python versions.
+        typing_attr=(
+            typing.Optional if IS_PYTHON_AT_LEAST_3_9 else typing.Union),
         is_supported=True,
         is_generic_user=False,
         is_typevared=False,
@@ -877,8 +941,24 @@ hints and must thus be segregated from those that do conform (which is most of
 them) to avoid spurious issues throughout downstream unit tests.
 '''
 
-# ....................{ HINTS                             }....................
-PEP_HINTS = tuple(PEP_HINT_TO_META.keys())
+# ....................{ SETS                              }....................
+PEP_HINTS_DEEP_IGNORABLE = frozenset((
+    # Arbitrary unions containing the shallowly ignorable "typing.Any" and
+    # "object" type hints.
+    typing.Union[typing.Any, float, str,],
+    typing.Union[complex, int, object,],
+))
 '''
-Tuple of various PEP-compliant type hints exercising well-known edge cases.
+Frozen set of **deeply ignorable PEP-compliant type hints** (i.e.,
+PEP-compliant type hints that are *not* shallowly ignorable and thus *not* in
+the low-level :attr:`beartype._util.hint.utilhintdata.HINTS_SHALLOW_IGNORABLE`
+set, but which are nonetheless ignorable and thus require dynamic testing by
+the high-level :func:`beartype._util.hint.utilhinttest.is_hint_ignorable`
+tester function to demonstrate this fact).
+'''
+
+# ....................{ TUPLES                            }....................
+PEP_HINTS = frozenset(PEP_HINT_TO_META.keys())
+'''
+Frozen set of PEP-compliant type hints exercising well-known edge cases.
 '''
